from setuptools import setup

setup(name='eratner-distributions',
      version='0.2',
      description='Gaussian distributions and Binomial Distributions',
      packages=['distributions'],
      zip_safe=False)
